inline void SyslogStream::close()
{
    eoi();
}
